@@ -3,7 +3,7 @@ Soft Potato pip version
 
 """
 
-__version__ = "0.18"
+__version__ = "0.19"
 __author__ = 'Oliver Rodriguez'
 
-__all__ = ['tech', 'calc', 'plot']
+__all__ = ['tech', 'calc', 'plot', 'sim']
